*****
Usage
*****

.. _Viewing the VAT analysis:

Viewing the VAT analysis
========================

Once this module has been activated you can see a breakdown of the company's
VAT and related sales and purchases by opening the
[:menuselection:`Financial --> Charts --> Open Chart of Tax Codes`].

.. tip::

   This module extends the chart of accounts provided by the
   :doc:`Account UK Module <account_uk:index>`, so the extra
   `Tax Codes <model-account.tax.code>` are only available if you are using
   the chart of accounts from that module.
